@@ -1,7 +1,6 @@
 import os
 
 from openai_proxy.completion import Completion
-from openai_proxy.price import Price
 
 
 api_key = os.environ.get("OPENAI_API_KEY")
@@ -18,5 +17,4 @@ __all__ = [
     "username",
     "course_id",
     "Completion",
-    "Price"
 ]
\ No newline at end of file
